# PyMathAlgoS

## 1. Installation

```bash
$ pip install pymathalgos
```

## 2. Functions

If you want to get the factorial value there is a factorial function:

```python
import pymathalgos
print(pymathalgos.factorial(3))
```